@@ -20,6 +20,13 @@ pub mod cosmos {
         }
     }
 
+    /// Granting of arbitrary privileges from one account to another.
+    pub mod authz {
+        pub mod v1beta1 {
+            include!("prost/cosmos.authz.v1beta1.rs");
+        }
+    }
+
     /// Balances.
     pub mod bank {
         pub mod v1beta1 {
@@ -58,6 +65,10 @@ pub mod cosmos {
             pub mod v1beta1 {
                 include!("prost/cosmos.base.reflection.v1beta1.rs");
             }
+
+            pub mod v2alpha1 {
+                include!("prost/cosmos.base.reflection.v2alpha1.rs");
+            }
         }
 
         /// Snapshots containing Tendermint state sync info.
@@ -107,6 +118,9 @@ pub mod cosmos {
         pub mod secp256k1 {
             include!("prost/cosmos.crypto.secp256k1.rs");
         }
+        pub mod secp256r1 {
+            include!("prost/cosmos.crypto.secp256r1.rs");
+        }
     }
 
     /// Messages and services handling token distribution
@@ -123,6 +137,13 @@ pub mod cosmos {
         }
     }
 
+    /// Allows accounts to grant fee allowances and to use fees from their accounts.
+    pub mod feegrant {
+        pub mod v1beta1 {
+            include!("prost/cosmos.feegrant.v1beta1.rs");
+        }
+    }
+
     /// Messages and services handling gentx's
     pub mod genutil {
         pub mod v1beta1 {
@@ -210,11 +231,34 @@ pub mod cosmwasm {
 pub mod ibc {
     /// IBC applications.
     pub mod applications {
+        /// Interchain accounts support.
+        pub mod interchain_accounts {
+            pub mod controller {
+                pub mod v1 {
+                    include!("prost/ibc.applications.interchain_accounts.controller.v1.rs");
+                }
+            }
+
+            pub mod host {
+                pub mod v1 {
+                    include!("prost/ibc.applications.interchain_accounts.host.v1.rs");
+                }
+            }
+
+            pub mod v1 {
+                include!("prost/ibc.applications.interchain_accounts.v1.rs");
+            }
+        }
+
         /// Transfer support.
         pub mod transfer {
             pub mod v1 {
                 include!("prost/ibc.applications.transfer.v1.rs");
             }
+
+            pub mod v2 {
+                include!("prost/ibc.applications.transfer.v2.rs");
+            }
         }
     }
 
@@ -267,6 +311,10 @@ pub mod ibc {
             pub mod v1 {
                 include!("prost/ibc.lightclients.solomachine.v1.rs");
             }
+
+            pub mod v2 {
+                include!("prost/ibc.lightclients.solomachine.v2.rs");
+            }
         }
         pub mod tendermint {
             pub mod v1 {
