@@ -67,7 +67,9 @@ pub struct TxBody {
     /// transaction.
     #[prost(message, repeated, tag = "1")]
     pub messages: ::prost::alloc::vec::Vec<::prost_types::Any>,
-    /// memo is any arbitrary memo to be added to the transaction
+    /// memo is any arbitrary note/comment to be added to the transaction.
+    /// WARNING: in clients, any publicly exposed text should not be called memo,
+    /// but should be called `note` instead (see <https://github.com/cosmos/cosmos-sdk/issues/9122>).
     #[prost(string, tag = "2")]
     pub memo: ::prost::alloc::string::String,
     /// timeout is the block height after which this transaction will not
@@ -194,7 +196,7 @@ pub struct GetTxsEventRequest {
     /// events is the list of transaction event type.
     #[prost(string, repeated, tag = "1")]
     pub events: ::prost::alloc::vec::Vec<::prost::alloc::string::String>,
-    /// pagination defines an pagination for the request.
+    /// pagination defines a pagination for the request.
     #[prost(message, optional, tag = "2")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
     #[prost(enumeration = "OrderBy", tag = "3")]
@@ -210,7 +212,7 @@ pub struct GetTxsEventResponse {
     /// tx_responses is the list of queried TxResponses.
     #[prost(message, repeated, tag = "2")]
     pub tx_responses: ::prost::alloc::vec::Vec<super::super::base::abci::v1beta1::TxResponse>,
-    /// pagination defines an pagination for the response.
+    /// pagination defines a pagination for the response.
     #[prost(message, optional, tag = "3")]
     pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
 }
@@ -237,8 +239,15 @@ pub struct BroadcastTxResponse {
 #[derive(Clone, PartialEq, ::prost::Message)]
 pub struct SimulateRequest {
     /// tx is the transaction to simulate.
+    /// Deprecated. Send raw tx bytes instead.
+    #[deprecated]
     #[prost(message, optional, tag = "1")]
     pub tx: ::core::option::Option<Tx>,
+    /// tx_bytes is the raw transaction.
+    ///
+    /// Since: cosmos-sdk 0.43
+    #[prost(bytes = "vec", tag = "2")]
+    pub tx_bytes: ::prost::alloc::vec::Vec<u8>,
 }
 /// SimulateResponse is the response type for the
 /// Service.SimulateRPC method.
@@ -269,6 +278,35 @@ pub struct GetTxResponse {
     #[prost(message, optional, tag = "2")]
     pub tx_response: ::core::option::Option<super::super::base::abci::v1beta1::TxResponse>,
 }
+/// GetBlockWithTxsRequest is the request type for the Service.GetBlockWithTxs
+/// RPC method.
+///
+/// Since: cosmos-sdk 0.45.2
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct GetBlockWithTxsRequest {
+    /// height is the height of the block to query.
+    #[prost(int64, tag = "1")]
+    pub height: i64,
+    /// pagination defines a pagination for the request.
+    #[prost(message, optional, tag = "2")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageRequest>,
+}
+/// GetBlockWithTxsResponse is the response type for the Service.GetBlockWithTxs method.
+///
+/// Since: cosmos-sdk 0.45.2
+#[derive(Clone, PartialEq, ::prost::Message)]
+pub struct GetBlockWithTxsResponse {
+    /// txs are the transactions in the block.
+    #[prost(message, repeated, tag = "1")]
+    pub txs: ::prost::alloc::vec::Vec<Tx>,
+    #[prost(message, optional, tag = "2")]
+    pub block_id: ::core::option::Option<::tendermint_proto::types::BlockId>,
+    #[prost(message, optional, tag = "3")]
+    pub block: ::core::option::Option<::tendermint_proto::types::Block>,
+    /// pagination defines a pagination for the response.
+    #[prost(message, optional, tag = "4")]
+    pub pagination: ::core::option::Option<super::super::base::query::v1beta1::PageResponse>,
+}
 /// OrderBy defines the sorting order
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash, PartialOrd, Ord, ::prost::Enumeration)]
 #[repr(i32)]
@@ -300,9 +338,10 @@ pub enum BroadcastMode {
 #[cfg_attr(docsrs, doc(cfg(feature = "grpc")))]
 #[doc = r" Generated client implementations."]
 pub mod service_client {
-    #![allow(unused_variables, dead_code, missing_docs)]
+    #![allow(unused_variables, dead_code, missing_docs, clippy::let_unit_value)]
     use tonic::codegen::*;
     #[doc = " Service defines a gRPC service for interacting with transactions."]
+    #[derive(Debug, Clone)]
     pub struct ServiceClient<T> {
         inner: tonic::client::Grpc<T>,
     }
@@ -320,17 +359,43 @@ pub mod service_client {
     impl<T> ServiceClient<T>
     where
         T: tonic::client::GrpcService<tonic::body::BoxBody>,
-        T::ResponseBody: Body + HttpBody + Send + 'static,
+        T::ResponseBody: Body + Send + 'static,
         T::Error: Into<StdError>,
-        <T::ResponseBody as HttpBody>::Error: Into<StdError> + Send,
+        <T::ResponseBody as Body>::Error: Into<StdError> + Send,
     {
         pub fn new(inner: T) -> Self {
             let inner = tonic::client::Grpc::new(inner);
             Self { inner }
         }
-        pub fn with_interceptor(inner: T, interceptor: impl Into<tonic::Interceptor>) -> Self {
-            let inner = tonic::client::Grpc::with_interceptor(inner, interceptor);
-            Self { inner }
+        pub fn with_interceptor<F>(
+            inner: T,
+            interceptor: F,
+        ) -> ServiceClient<InterceptedService<T, F>>
+        where
+            F: tonic::service::Interceptor,
+            T: tonic::codegen::Service<
+                http::Request<tonic::body::BoxBody>,
+                Response = http::Response<
+                    <T as tonic::client::GrpcService<tonic::body::BoxBody>>::ResponseBody,
+                >,
+            >,
+            <T as tonic::codegen::Service<http::Request<tonic::body::BoxBody>>>::Error:
+                Into<StdError> + Send + Sync,
+        {
+            ServiceClient::new(InterceptedService::new(inner, interceptor))
+        }
+        #[doc = r" Compress requests with `gzip`."]
+        #[doc = r""]
+        #[doc = r" This requires the server to support it otherwise it might respond with an"]
+        #[doc = r" error."]
+        pub fn send_gzip(mut self) -> Self {
+            self.inner = self.inner.send_gzip();
+            self
+        }
+        #[doc = r" Enable decompressing responses with `gzip`."]
+        pub fn accept_gzip(mut self) -> Self {
+            self.inner = self.inner.accept_gzip();
+            self
         }
         #[doc = " Simulate simulates executing a transaction for estimating gas usage."]
         pub async fn simulate(
@@ -394,17 +459,23 @@ pub mod service_client {
                 http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/GetTxsEvent");
             self.inner.unary(request.into_request(), path, codec).await
         }
-    }
-    impl<T: Clone> Clone for ServiceClient<T> {
-        fn clone(&self) -> Self {
-            Self {
-                inner: self.inner.clone(),
-            }
-        }
-    }
-    impl<T> std::fmt::Debug for ServiceClient<T> {
-        fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-            write!(f, "ServiceClient {{ ... }}")
+        #[doc = " GetBlockWithTxs fetches a block with decoded txs."]
+        #[doc = ""]
+        #[doc = " Since: cosmos-sdk 0.45.2"]
+        pub async fn get_block_with_txs(
+            &mut self,
+            request: impl tonic::IntoRequest<super::GetBlockWithTxsRequest>,
+        ) -> Result<tonic::Response<super::GetBlockWithTxsResponse>, tonic::Status> {
+            self.inner.ready().await.map_err(|e| {
+                tonic::Status::new(
+                    tonic::Code::Unknown,
+                    format!("Service was not ready: {}", e.into()),
+                )
+            })?;
+            let codec = tonic::codec::ProstCodec::default();
+            let path =
+                http::uri::PathAndQuery::from_static("/cosmos.tx.v1beta1.Service/GetBlockWithTxs");
+            self.inner.unary(request.into_request(), path, codec).await
         }
     }
 }
